import { CanActivate, ExecutionContext, Injectable, UnauthorizedException } from '@nestjs/common';
import { ConfigService } from '@nestjs/config';
import { Observable, of } from 'rxjs';
import { APP__ACCESS_TOKEN } from '../models/consts/env-vars.const';

@Injectable()
export class AccessTokenGuard implements CanActivate {
    constructor(private readonly _configService: ConfigService) {}

    canActivate(context: ExecutionContext): Observable<boolean> {
        const req = context.switchToHttp().getRequest();
        const token = req.headers['x-access-token'];

        if (!token || token !== this._configService.get<string>(APP__ACCESS_TOKEN)) {
            throw new UnauthorizedException();
        }

        return of(true);
    }
}
